@@ -834,9 +834,10 @@ QVariant AssetParameterModel::parseAttribute(const QString &attribute, const QDo
             filter.remove(filter.indexOf(QLatin1String(")")) - 1, -1);
             QStringList fileExt = filter.split(QStringLiteral(" "));
             // check for Kdenlive installed luts files
-            QStringList customLuts = QStandardPaths::locateAll(QStandardPaths::AppLocalDataLocation, QStringLiteral("luts"), QStandardPaths::LocateDirectory);
+            const QStringList customLuts =
+                QStandardPaths::locateAll(QStandardPaths::AppLocalDataLocation, QStringLiteral("luts"), QStandardPaths::LocateDirectory);
             QStringList results;
-            for (const QString &folderpath : std::as_const(customLuts)) {
+            for (const QString &folderpath : customLuts) {
                 QDir dir(folderpath);
                 QDirIterator it(dir.absolutePath(), fileExt, QDir::Files, QDirIterator::Subdirectories);
                 while (it.hasNext()) {
@@ -1041,7 +1042,7 @@ QVector<QPair<QString, QVariant>> AssetParameterModel::getAllParameters() const
         if (!param.first.isEmpty()) {
             QModelIndex ix = index(m_rows.indexOf(param.first), 0);
             if (m_params.at(param.first).type == ParamType::MultiSwitch) {
-                // Multiswitch param value is not updated on change, fo fetch real value now
+                // Multiswitch param value is not updated on change, go fetch real value now
                 QVariant multiVal = data(ix, AssetParameterModel::ValueRole).toString();
                 res.push_back(QPair<QString, QVariant>(param.first, multiVal));
                 continue;
@@ -1727,7 +1728,7 @@ bool AssetParameterModel::isDefault() const
             }
         }
         if (currentRow.value != value) {
-            qDebug() << "======= ERROR COMPARING PARMA VALUES:\n" << currentRow.value << " = " << value;
+            qDebug() << "======= ERROR COMPARING PARAM VALUES:\n" << currentRow.value << " = " << value;
             return false;
         }
     }
