@@ -102,11 +102,12 @@ KeyframeImport::KeyframeImport(const QString &animData, std::shared_ptr<AssetPar
     }
     if (!json.isArray()) {
         qDebug() << "Error : Json file should be an array";
+        close();
         return;
     }
     auto list = json.array();
     int ix = 0;
-    for (const auto &entry : qAsConst(list)) {
+    for (const auto &entry : std::as_const(list)) {
         if (!entry.isObject()) {
             qDebug() << "Warning : Skipping invalid marker data";
             continue;
@@ -261,7 +262,7 @@ KeyframeImport::KeyframeImport(const QString &animData, std::shared_ptr<AssetPar
         ix++;
     }
     if (count == 4) {
-        // add an option to map to a a fake rectangle (pretend position params are a mlt rect)
+        // add an option to map to a fake rectangle (pretend position params are a mlt rect)
         m_targetCombo->insertItem(ix, i18n("Rectangle"));
     }
     ix = 0;
@@ -751,7 +752,6 @@ QString KeyframeImport::selectedTarget() const
 
 void KeyframeImport::drawKeyFrameChannels(QPixmap &pix, int in, int out, int limitKeyframes, const QColor &textColor)
 {
-    // qDebug() << "============= DRAWING KFR CHANNS: " << m_dataCombo->currentData().toString();
     std::shared_ptr<Mlt::Properties> animData = KeyframeModel::getAnimation(m_model, m_dataCombo->currentData().toString());
     QRect br(0, 0, pix.width(), pix.height());
     double frameFactor = double(out - in) / br.width();
@@ -827,7 +827,6 @@ void KeyframeImport::drawKeyFrameChannels(QPixmap &pix, int in, int out, int lim
         if (xDist > 0) {
             painter.setPen(cX);
             int val = int((rect.x - xOffset) * maxHeight / xDist);
-            // qDebug() << "// DRAWINC CURVE : " << rect.x << ", POS: " << (int(i * frameFactor) + in) << ", RESULT: " << val;
             painter.drawLine(i, maxHeight - val, i, maxHeight);
         }
         if (yDist > 0) {
@@ -838,7 +837,6 @@ void KeyframeImport::drawKeyFrameChannels(QPixmap &pix, int in, int out, int lim
         if (wDist > 0) {
             painter.setPen(cW);
             int val = int((rect.w - wOffset) * maxHeight / wDist);
-            // qDebug() << "// OFFSET: " << wOffset << ", maxH: " << maxHeight << ", wDIst:" << wDist << " = " << val;
             painter.drawLine(i, maxHeight - val, i, maxHeight);
         }
         if (hDist > 0) {
@@ -909,10 +907,10 @@ void KeyframeImport::importSelectedData()
     int targetAlign = m_alignTargetCombo->currentData().toInt();
     QLocale locale; // Import from clipboard – OK to use locale here?
     locale.setNumberOptions(QLocale::OmitGroupSeparator);
-    // wether we are mapping to a fake rectangle
+    // whether we are mapping to a fake rectangle
     bool fakeRect = !m_targetCombo->currentData().toModelIndex().isValid() && m_targetCombo->currentText() == i18n("Rectangle");
     bool useOpacity = m_dataCombo->currentData(OpacityRole).toBool();
-    for (const auto &ix : qAsConst(m_indexes)) {
+    for (const auto &ix : std::as_const(m_indexes)) {
         // update keyframes in other indexes
         KeyframeModel *km = kfrModel->getKeyModel(ix);
         qDebug() << "== " << ix << " = " << m_targetCombo->currentData().toModelIndex();
@@ -945,8 +943,8 @@ void KeyframeImport::importSelectedData()
                 QVariant current = km->getInterpolatedValue(frame);
                 if (convertMode == ImportRoles::SimpleValue) {
                     double dval = animData->anim_get_double("key", frame);
-                    km->addKeyframe(GenTime(frame - m_inPoint->getPosition() + m_offsetPoint->getPosition(), pCore->getCurrentFps()), KeyframeType(type), dval,
-                                    true, undo, redo);
+                    km->addKeyframe(GenTime(frame - m_inPoint->getPosition() + m_offsetPoint->getPosition(), pCore->getCurrentFps()),
+                                    KeyframeType::KeyframeEnum(type), dval, true, undo, redo);
                     continue;
                 }
                 QStringList kfrData = current.toString().split(QLatin1Char(' '));
@@ -1105,7 +1103,7 @@ void KeyframeImport::importSelectedData()
                     kfrData[3] = locale.toString(int(rect.h));
                     break;
                 }
-                // map the fake rectangle internaly to the right params
+                // map the fake rectangle internally to the right params
                 QString name = ix.data(AssetParameterModel::NameRole).toString();
                 QSize frameSize = pCore->getCurrentFrameSize();
                 if (name.contains("Position X") &&
@@ -1131,8 +1129,8 @@ void KeyframeImport::importSelectedData()
                 } else {
                     current = kfrData.join(QLatin1Char(' '));
                 }
-                km->addKeyframe(GenTime(frame - m_inPoint->getPosition() + m_offsetPoint->getPosition(), pCore->getCurrentFps()), KeyframeType(type), current,
-                                true, undo, redo);
+                km->addKeyframe(GenTime(frame - m_inPoint->getPosition() + m_offsetPoint->getPosition(), pCore->getCurrentFps()),
+                                KeyframeType::KeyframeEnum(type), current, true, undo, redo);
             }
         } else {
             int frame = 0;
@@ -1147,8 +1145,8 @@ void KeyframeImport::importSelectedData()
                 }
                 // frame += (m_inPoint->getPosition() - m_offsetPoint->getPosition());
                 QVariant current = km->getInterpolatedValue(frame);
-                km->addKeyframe(GenTime(frame - m_inPoint->getPosition() + m_offsetPoint->getPosition(), pCore->getCurrentFps()), KeyframeType(type), current,
-                                true, undo, redo);
+                km->addKeyframe(GenTime(frame - m_inPoint->getPosition() + m_offsetPoint->getPosition(), pCore->getCurrentFps()),
+                                KeyframeType::KeyframeEnum(type), current, true, undo, redo);
             }
         }
     }
@@ -1165,6 +1163,10 @@ int KeyframeImport::getImportType() const
 
 void KeyframeImport::updateView()
 {
+    if (m_targetCombo == nullptr) {
+        // Invalid data
+        return;
+    }
     QPersistentModelIndex ix = m_targetCombo->currentData().toModelIndex();
     QString paramName = m_model->data(ix, AssetParameterModel::NameRole).toString();
 
@@ -1184,7 +1186,7 @@ void KeyframeImport::updateView()
     animData->set("original", m_originalParams.value(ix).toUtf8().constData());
     std::shared_ptr<Mlt::Animation> animo(new Mlt::Animation(animData->get_animation("original")));
     animo->interpolate();
-    // wether we are mapping to a fake rectangle
+    // whether we are mapping to a fake rectangle
     bool fakeRect = !m_targetCombo->currentData().toModelIndex().isValid() && m_targetCombo->currentText() == i18n("Rectangle");
     // Import our keyframes
     int frame = 0;
@@ -1357,7 +1359,7 @@ void KeyframeImport::updateView()
             kfrData[3] = locale.toString(int(rect.h));
             break;
         }
-        // map the fake rectangle internaly to the right params
+        // map the fake rectangle internally to the right params
         QString name = ix.data(AssetParameterModel::NameRole).toString();
         QSize frameSize = pCore->getCurrentFrameSize();
         bool doubleParameter = false;
