@@ -27,9 +27,6 @@ UrlListParamWidget::UrlListParamWidget(std::shared_ptr<AssetParameterModel> mode
     const QString comment = m_model->data(m_index, AssetParameterModel::CommentRole).toString();
     const QString configFile = m_model->data(m_index, AssetParameterModel::NewStuffRole).toString();
 
-    // setup the comment
-    setToolTip(comment);
-    m_labelComment->setText(comment);
     m_widgetComment->setHidden(true);
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
     m_list->setIconSize(QSize(50, 30));
@@ -382,8 +379,8 @@ void UrlListParamWidget::addItemsInSameFolder(const QString currentValue, QMap<Q
 {
     QDir dir = QFileInfo(currentValue).absoluteDir();
     if (dir.exists()) {
-        QStringList entrys = dir.entryList(m_fileExt, QDir::Files);
-        for (const auto &filename : std::as_const(entrys)) {
+        QStringList entries = dir.entryList(m_fileExt, QDir::Files);
+        for (const auto &filename : std::as_const(entries)) {
             const QString path = dir.absoluteFilePath(filename);
             if (std::find((*listValues).cbegin(), (*listValues).cend(), path) == (*listValues).cend()) {
                 (*listValues).insert(QFileInfo(filename).baseName(), path);
