@@ -42,9 +42,9 @@ ClipJobManager::ClipJobManager(AbstractTask::JOBTYPE type, QWidget *parent)
     connect(button_delete, &QToolButton::clicked, this, &ClipJobManager::deleteJob);
 
     job_params->setToolTip(i18n("Arguments for the command line script"));
-    job_params->setWhatsThis(
-        xi18nc("@info:whatsthis",
-               "<b>{source}</b> will be replaced by the Bin Clip source file path, <b>{param1}</b> will be replaced by the first parameter value, <b>{param2}</b> will be replaced by the second parameter value, <b>{output}</b> will be replaced by the output file name."));
+    job_params->setWhatsThis(xi18nc(
+        "@info:whatsthis", "<b>{source}</b> will be replaced by the Bin Clip source file path, <b>{param1}</b> will be replaced by the first parameter value, "
+                           "<b>{param2}</b> will be replaced by the second parameter value, <b>{output}</b> will be replaced by the output file name."));
     destination_pattern->setToolTip(i18n("File extension for the output file"));
     destination_pattern->setWhatsThis(
         xi18nc("@info:whatsthis",
@@ -279,7 +279,7 @@ QMap<QString, QString> ClipJobManager::getClipJobNames()
     while (i.hasNext()) {
         i.next();
         if (!i.value().isEmpty()) {
-            newIds.insert(QString("%1;%2").arg(i.key(), id2s.value(i.key())), i.value());
+            newIds.insert(QStringLiteral("%1;%2").arg(i.key(), id2s.value(i.key())), i.value());
         }
     }
     // Add the 3 internal jobs
