@@ -30,14 +30,21 @@
 #include <mlt++/MltTransition.h>
 
 #ifdef CRASH_AUTO_TEST
+#ifdef __GNUC__
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-parameter"
 #pragma GCC diagnostic ignored "-Wsign-conversion"
 #pragma GCC diagnostic ignored "-Wfloat-equal"
 #pragma GCC diagnostic ignored "-Wshadow"
 #pragma GCC diagnostic ignored "-Wpedantic"
+#endif
+
 #include <rttr/registration>
+
+#ifdef __GNUC__
 #pragma GCC diagnostic pop
+#endif
+
 RTTR_REGISTRATION
 {
     using namespace rttr;
@@ -253,6 +260,7 @@ QHash<int, QByteArray> TimelineItemModel::roleNames() const
     roles[StartRole] = "start";
     roles[MixRole] = "mixDuration";
     roles[MixCutRole] = "mixCut";
+    roles[MixEndDurationRole] = "mixEndDuration";
     roles[DurationRole] = "duration";
     roles[MaxDurationRole] = "maxDuration";
     roles[MarkersRole] = "markers";
@@ -403,6 +411,8 @@ QVariant TimelineItemModel::data(const QModelIndex &index, int role) const
             return clip->getMixDuration();
         case MixCutRole:
             return clip->getMixCutPosition();
+        case MixEndDurationRole:
+            return getEndMixDuration(id);
         case ClipThumbRole:
             return clip->clipThumbPath();
         case ReloadAudioThumbRole:
@@ -797,6 +807,9 @@ void TimelineItemModel::buildTrackCompositing(bool rebuild)
     QString composite;
     if (pCore->currentDoc()->getSequenceProperty(m_uuid, QStringLiteral("compositing"), QStringLiteral("1")).toInt() > 0) {
         composite = TransitionsRepository::get()->getCompositingTransition();
+        if (composite.isEmpty()) {
+            pCore->displayMessage(i18n("Could not setup track compositing, check your install"), MessageType::ErrorMessage);
+        }
     }
     int videoTracks = 0;
     int audioTracks = 0;
@@ -840,9 +853,6 @@ void TimelineItemModel::buildTrackCompositing(bool rebuild)
     if (isMultiTrack) {
         pCore->enableMultiTrack(true);
     }
-    if (composite.isEmpty()) {
-        pCore->displayMessage(i18n("Could not setup track compositing, check your install"), MessageType::ErrorMessage);
-    }
 }
 
 void TimelineItemModel::notifyChange(const QModelIndex &topleft, const QModelIndex &bottomright, int role)
@@ -1175,3 +1185,23 @@ QList<std::shared_ptr<KeyframeModelList>> TimelineItemModel::getGroupKeyframeMod
     }
     return models;
 }
+
+int TimelineItemModel::getEndMixDuration(int cid) const
+{
+    Q_ASSERT(isClip(cid));
+    int tid = m_allClips.at(cid)->getCurrentTrackId();
+    qDebug() << ":::: CHECKING MIX  FOR: " << cid;
+    if (tid > -1) {
+        MixInfo mixData = getTrackById_const(tid)->getMixInfo(cid).second;
+        if (mixData.secondClipId > -1) {
+            qDebug() << ":::: CLIP HAS END MIX WITH: " << mixData.secondClipId;
+            MixInfo mixData2 = getTrackById_const(tid)->getMixInfo(mixData.secondClipId).first;
+            qDebug() << ":::: GOT OFFSET DATA FOR CLIP: " << cid << " = " << mixData2.mixOffset;
+            return mixData2.firstClipInOut.second - mixData2.secondClipInOut.first;
+            // return {mixData.secondClipInOut.first, mixData.firstClipInOut.second};
+        } else {
+            qDebug() << ":::: CLIP HAS NO END MIX... FIRST MIX:" << getTrackById_const(tid)->getMixInfo(cid).first.firstClipId;
+        }
+    }
+    return 0;
+}
