@@ -20,12 +20,13 @@ public:
     void unsetModel();
     ObjectId stackOwner() const;
     void refreshTracks();
+    void openCompositionHelp();
 
-private slots:
+private Q_SLOTS:
     void updateTrack(int newTrack);
     void checkCompoTrack();
 
-signals:
+Q_SIGNALS:
     void seekToTransPos(int pos);
 
 private:
